@@ -10,7 +10,6 @@ module Codec.Encryption.OpenPGP.BlockCipher (
   , withSymmetricCipher
 ) where
 
-import Codec.Encryption.OpenPGP.Internal
 import Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes (HOWrappedOldCCT(..))
 import Codec.Encryption.OpenPGP.Internal.Cryptonite (HOWrappedCCT(..))
 import Codec.Encryption.OpenPGP.Internal.HOBlockCipher
@@ -19,6 +18,7 @@ import Codec.Encryption.OpenPGP.Types
 import qualified Crypto.Cipher.Blowfish as Blowfish
 import qualified Crypto.Cipher.TripleDES as TripleDES
 import qualified Crypto.Cipher.AES as AES
+import qualified Crypto.Cipher.Camellia as Camellia
 import qualified Crypto.Nettle.Ciphers as CNC
 import qualified Data.ByteString as B
 
@@ -37,6 +37,9 @@ withSymmetricCipher Blowfish key f = (cipherInit key :: Either String (HOWrapped
 withSymmetricCipher AES128 key f = (cipherInit key :: Either String (HOWrappedCCT AES.AES128)) >>= f
 withSymmetricCipher AES192 key f = (cipherInit key :: Either String (HOWrappedCCT AES.AES192)) >>= f
 withSymmetricCipher AES256 key f = (cipherInit key :: Either String (HOWrappedCCT AES.AES256)) >>= f
+withSymmetricCipher Camellia128 key f = (cipherInit key :: Either String (HOWrappedCCT Camellia.Camellia128)) >>= f
+withSymmetricCipher Camellia192 key f = (cipherInit key :: Either String (HOWrappedOldCCT CNC.Camellia192)) >>= f
+withSymmetricCipher Camellia256 key f = (cipherInit key :: Either String (HOWrappedOldCCT CNC.Camellia256)) >>= f
 
 -- in octets; FIXME: co-opt Cipher's cipherKeySize or not?
 keySize :: SymmetricAlgorithm -> Int
@@ -51,4 +54,7 @@ keySize AES128 = 16
 keySize AES192 = 24
 keySize AES256 = 32
 keySize Twofish = 32
+keySize Camellia128 = 16
+keySize Camellia192 = 24
+keySize Camellia256 = 32
 keySize (OtherSA _) = undefined
