@@ -1,5 +1,5 @@
 -- Compression.hs: OpenPGP (RFC4880) compression and decompression
--- Copyright © 2012-2013  Clint Adams
+-- Copyright © 2012-2015  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
@@ -13,17 +13,15 @@ import qualified Codec.Compression.Zlib as Zlib
 import qualified Codec.Compression.Zlib.Raw as ZlibRaw
 import Codec.Encryption.OpenPGP.Serialize ()
 import Codec.Encryption.OpenPGP.Types
-import qualified Data.ByteString as B
-import qualified Data.ByteString.Lazy as BL
-import Data.Serialize (get, put)
-import Data.Serialize.Get (runGet)
-import Data.Serialize.Put (runPut)
+import Data.Binary (get, put)
+import Data.Binary.Get (runGetOrFail)
+import Data.Binary.Put (runPut)
 
 decompressPkt :: Pkt -> [Pkt]
 decompressPkt (CompressedDataPkt algo bs) =
-    case (runGet get . B.concat . BL.toChunks) (dfunc algo (BL.fromChunks [bs])) of
-                       Left _ -> []
-                       Right packs -> unBlock packs
+    case runGetOrFail get (dfunc algo bs) of
+        Left _ -> []
+        Right (_, _, packs) -> unBlock packs
     where
         dfunc ZIP = ZlibRaw.decompress
         dfunc ZLIB = Zlib.decompress
@@ -32,10 +30,10 @@ decompressPkt (CompressedDataPkt algo bs) =
 decompressPkt p = [p]
 
 compressPkts :: CompressionAlgorithm -> [Pkt] -> Pkt
-compressPkts ca packs = do
+compressPkts ca packs =
     let bs = runPut $ put (Block packs)
-        cbs = B.concat . BL.toChunks $ cfunc ca (BL.fromChunks [bs])
-    CompressedDataPkt ca cbs
+        cbs = cfunc ca bs
+        in CompressedDataPkt ca cbs
     where
         cfunc ZIP = ZlibRaw.compress
         cfunc ZLIB = Zlib.compress
