@@ -117,6 +117,6 @@ truncatingVerify hashAlg pk (DSA.Signature r s) m
           w       = fromJust $ inverse s q
           u1      = (hm*w) `mod` q
           u2      = (r*w) `mod` q
-          v       = ((expFast g u1 p) * (expFast y u2 p)) `mod` p `mod` q
+          v       = (expFast g u1 p * expFast y u2 p) `mod` p `mod` q
           dsaTruncate bs = let lbs = BL.fromStrict bs in if countBits lbs > fromIntegral dsaQLen then B.take (dsaQLen `div` 8) bs else bs -- FIXME: uneven bits
-          dsaQLen = numBits $ q
+          dsaQLen = numBits q
