@@ -10,8 +10,6 @@ module Codec.Encryption.OpenPGP.KeyInfo (
 
 import qualified Crypto.PubKey.RSA as RSA
 import qualified Crypto.PubKey.DSA as DSA
-import qualified Crypto.Hash.MD5 as MD5
-import qualified Crypto.Hash.SHA1 as SHA1
 import qualified Data.ByteString as B
 import Data.Bits (shiftR)
 import Data.List (unfoldr)
