@@ -1,8 +1,10 @@
 -- KeyringParser.hs: OpenPGP (RFC4880) transferable keys parsing
--- Copyright © 2012-2015  Clint Adams
+-- Copyright © 2012-2016  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
+{-# LANGUAGE CPP #-}
+
 module Codec.Encryption.OpenPGP.KeyringParser (
    parseAChunk
  , finalizeParsing
@@ -24,8 +26,16 @@ module Codec.Encryption.OpenPGP.KeyringParser (
  , broken
 ) where
 
-import Control.Applicative (many, (<$>), (<|>))
-import Data.Monoid (Monoid, (<>), mconcat)
+import Control.Applicative (many, (<|>))
+#if !MIN_VERSION_base(4,8,0)
+import Control.Applicative ((<$>))
+#endif
+
+#if !MIN_VERSION_base(4,8,0)
+import Data.Monoid (Monoid, mconcat)
+#endif
+import Data.Monoid ((<>))
+
 import Data.Text (Text)
 
 import Codec.Encryption.OpenPGP.Types
