@@ -17,6 +17,7 @@ import Codec.Encryption.OpenPGP.CFB (decryptNoNonce, encryptNoNonce)
 import Codec.Encryption.OpenPGP.Serialize (getSecretKey)
 import Codec.Encryption.OpenPGP.S2K (skesk2Key, string2Key)
 import qualified Crypto.Hash as CH
+import Crypto.Number.ModArithmetic (inverse)
 import Crypto.Random.EntropyPool (createEntropyPool, getEntropyFrom)
 import qualified Data.ByteArray as BA
 import qualified Data.ByteString as B
@@ -80,13 +81,8 @@ encryptSKey (RSAPrivateKey (RSA_PrivateKey (R.PrivateKey _ d p q _ _ _))) s2k iv
         algospecific = runPut $ put (MPI d) >> put (MPI p) >> put (MPI q) >> put (MPI u)
         cksum = CH.hashlazy algospecific :: CH.Digest CH.SHA1
         payload = algospecific `BL.append` BL.fromStrict (BA.convert cksum)
-        u = inverse q p
+        Just u = inverse p q
 encryptSKey _ _ _ _ = error "Non-RSA keytypes not handled yet" -- FIXME: do DSA and ElGamal
 
-inverse :: Integral a => a -> a -> a
-inverse _ 1 = 1
-inverse q p = (n * q + 1) `div` p
-    where n = p - inverse p (q `mod` p)
-
 reencryptSecretKeyIO :: SecretKey -> BL.ByteString -> IO SecretKey
 reencryptSecretKeyIO sk pp = encryptPrivateKeyIO (_secretKeySKAddendum sk) pp >>= \n -> return sk { _secretKeySKAddendum = n }
