@@ -3,12 +3,17 @@
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
+{-# LANGUAGE CPP #-}
+
 module Codec.Encryption.OpenPGP.Serialize (
    putSKAddendum
  , getSecretKey
 ) where
 
-import Control.Applicative ((<$>), many, some)
+#if !MIN_VERSION_base(4,8,0)
+import Control.Applicative ((<$>))
+#endif
+import Control.Applicative (many, some)
 import Control.Lens ((^.), _1)
 import Control.Monad (guard, liftM, replicateM, replicateM_)
 import Crypto.Number.Basic (numBits)
@@ -25,7 +30,9 @@ import Data.Binary (Binary, get, put)
 import Data.Binary.Get (Get, getByteString, getLazyByteString, getRemainingLazyByteString, getWord8, getWord16be, getWord32be, getWord16le, runGetOrFail, ByteOffset)
 import Data.Binary.Put (Put, putWord8, putWord16be, putWord32be, putByteString, putLazyByteString, putWord16le, runPut)
 import qualified Data.Foldable as F
+#if !MIN_VERSION_base(4,8,0)
 import Data.Monoid (mempty)
+#endif
 import Data.Set (Set)
 import qualified Data.Set as Set
 import qualified Data.Text as T
@@ -35,7 +42,7 @@ import Data.Word (Word8, Word32)
 import Data.Maybe (fromMaybe)
 import Network.URI (nullURI, parseURI, uriToString)
 
-import Codec.Encryption.OpenPGP.Internal (countBits, pubkeyToMPIs, multiplicativeInverse)
+import Codec.Encryption.OpenPGP.Internal (pubkeyToMPIs, multiplicativeInverse)
 import Codec.Encryption.OpenPGP.Types
 
 instance Binary SigSubPacket where
@@ -875,15 +882,16 @@ putSKAddendum (SUUnencrypted sk checksum) = do
 putSKAddendum _ = fail "Type not supported"
 
 symEncBlockSize :: SymmetricAlgorithm -> Int
-symEncBlockSize (Plaintext) = 0
-symEncBlockSize (IDEA) = 8
-symEncBlockSize (TripleDES) = 8
-symEncBlockSize (CAST5) = 8
-symEncBlockSize (Blowfish) = 8
-symEncBlockSize (AES128) = 16
-symEncBlockSize (AES192) = 16
-symEncBlockSize (AES256) = 16
-symEncBlockSize (Twofish) = 16
+symEncBlockSize Plaintext = 0
+symEncBlockSize IDEA = 8
+symEncBlockSize TripleDES = 8
+symEncBlockSize CAST5 = 8
+symEncBlockSize Blowfish = 8
+symEncBlockSize AES128 = 16
+symEncBlockSize AES192 = 16
+symEncBlockSize AES256 = 16
+symEncBlockSize Twofish = 16
+symEncBlockSize Camellia128 = 16
 symEncBlockSize _ = 8 -- FIXME
 
 decodeIterationCount :: Word8 -> IterationCount
