@@ -3,6 +3,8 @@
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
+{-# LANGUAGE CPP #-}
+
 module Codec.Encryption.OpenPGP.Signatures (
    verifySigWith
  , verifyAgainstKeyring
@@ -10,7 +12,9 @@ module Codec.Encryption.OpenPGP.Signatures (
  , verifyTKWith
 ) where
 
-import Control.Applicative ((<$>),(<*>))
+#if !MIN_VERSION_base(4,8,0)
+import Control.Applicative ((<$>), (<*>))
+#endif
 import Control.Error.Util (hush)
 import Control.Lens ((^.), _1)
 import Control.Monad (liftM2)
